@@ -21,7 +21,6 @@ __all__ = ('Evaluate',)
 
 # Initialize a module-wide logger
 logger = lg.getLogger(__name__)
-logger.setLevel(lg.INFO)
 
 
 class Evaluate:
@@ -610,6 +609,11 @@ class Evaluate:
                 alphas.append(alpha)
                 logger.info(f"{alpha:.10f}\t {num_eci}\t {cv[i]:.10f}")
 
+        # add the cv scores
+        self._cv_scores = []
+        for alpha, cv_score in zip(alphas, cv):
+            self._cv_scores.append({'alpha': alpha, 'cv': cv_score})
+
         return alphas, cv
 
     def cv_for_alpha(self, alphas: List[float]) -> None:
